@@ -1021,6 +1021,8 @@ class NmrDataSet:
                 self.nmrdat[k][l].proc.proc3s_text = f.read()
                 f.close()
 
+        self.cf.current_directory = data_set_name
+        self.cf.save_config()
         # end load
 
     def noise_filtering(self):
@@ -1344,6 +1346,9 @@ class NmrDataSet:
                 f = open(f_name, 'w')
                 f.write(self.nmrdat[k][l].acq.acqu3s_text)
                 f.close()
+
+        self.cf.current_directory = data_set_name
+        self.cf.save_config()
         # end save
 
     def scale_spectra(self):
